@@ -279,7 +279,13 @@ def _get_pkg_resource_distributions():
     return lambda: pkg_resources.working_set
 
 
-def _initPackageToDistributionName():
+def getDistributions():
+    # Cached result, pylint: disable=global-statement
+    global _package_to_distribution
+
+    if _package_to_distribution is not None:
+        return _package_to_distribution
+
     try:
         if isExperimental("force-pkg-resources-metadata"):
             raise ImportError
@@ -296,8 +302,7 @@ def _initPackageToDistributionName():
             # No pip installed, not very many distributions in that case.
             distributions = lambda: ()
 
-    # Cyclic dependency
-    result = {}
+    _package_to_distribution = {}
 
     for distribution in distributions():
         distribution_name = getDistributionName(distribution)
@@ -324,19 +329,19 @@ is typically caused by corruption of its installation."""
 
             package_name = ModuleName(package_name)
 
-            if package_name not in result:
-                result[package_name] = set()
+            if package_name not in _package_to_distribution:
+                _package_to_distribution[package_name] = OrderedSet()
 
             # Skip duplicates, e.g. user package vs. site package installation.
             if any(
                 distribution_name == getDistributionName(dist)
-                for dist in result[package_name]
+                for dist in _package_to_distribution[package_name]
             ):
                 continue
 
-            result[package_name].add(distribution)
+            _package_to_distribution[package_name].add(distribution)
 
-    return result
+    return _package_to_distribution
 
 
 def getDistributionsFromModuleName(module_name):
@@ -345,24 +350,17 @@ def getDistributionsFromModuleName(module_name):
     This can be more than one in case of namespace modules.
     """
 
-    # Cached result, pylint: disable=global-statement
-    global _package_to_distribution
-
-    if _package_to_distribution is None:
-        _package_to_distribution = _initPackageToDistributionName()
+    distributions = getDistributions()
 
     module_name = ModuleName(module_name)
     # Go upwards until we find something, such that contained module names are
     # usable too.
-    while (
-        module_name not in _package_to_distribution
-        and module_name.getPackageName() is not None
-    ):
+    while module_name not in distributions and module_name.getPackageName() is not None:
         module_name = module_name.getPackageName()
 
     return tuple(
         sorted(
-            _package_to_distribution.get(module_name, ()),
+            distributions.get(module_name, ()),
             key=getDistributionName,
         )
     )
@@ -494,7 +492,7 @@ def isDistributionPipPackage(distribution_name):
 
 
 def isDistributionPoetryPackage(distribution_name):
-    return getDistributionInstallerName(distribution_name).startswith("poetry")
+    return getDistributionInstallerName(distribution_name).lower().startswith("poetry")
 
 
 def isDistributionSystemPackage(distribution_name):
@@ -539,8 +537,8 @@ def getDistributionInstallerName(distribution_name):
     We might care of pip, anaconda, Debian, or whatever installed a
     package.
     """
-
     # many cases due to fallback variants, pylint: disable=too-many-branches
+    assert isValidDistributionName(distribution_name), repr(distribution_name)
 
     if distribution_name not in _distribution_to_installer:
         distribution = getDistribution(distribution_name)
@@ -555,6 +553,14 @@ def getDistributionInstallerName(distribution_name):
 
             if installer_name:
                 _distribution_to_installer[distribution_name] = installer_name
+
+                if installer_name.lower().startswith("poetry") and isAnacondaPython():
+                    metadata_logger.sysexit(
+                        """\
+Error, cannot use poetry and conda combined in a virtualenv, due \
+to poetry corrupting installer information. Use either pure conda \
+or poetry virtualenv."""
+                    )
             elif isAnacondaPython():
                 _distribution_to_installer[distribution_name] = "conda"
             elif isPdmPackageInstallation(distribution):
@@ -572,7 +578,7 @@ def getDistributionInstallerName(distribution_name):
                         "dist-packages" in distribution_path_parts
                         and "local" not in distribution_path_parts
                     ):
-                        _distribution_to_installer[distribution_name] = "Debian"
+                        _distribution_to_installer[distribution_name] = "debian"
                     else:
                         _distribution_to_installer[distribution_name] = "Unknown"
                 else:
@@ -666,7 +672,10 @@ def _getEntryPointGroup(group_name):
 
         entry_points = pkg_resources.entry_points
 
-    return entry_points(group=group_name)
+    try:
+        return entry_points(group=group_name)
+    except TypeError:
+        return entry_points().get(group_name, ())
 
 
 EntryPointDescription = makeNamedtupleClass(
